summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorFederico Mena Quintero <federico@ximian.com>2005-04-15 21:25:59 +0000
committerFederico Mena Quintero <federico@src.gnome.org>2005-04-15 21:25:59 +0000
commit64cd25f5829f0a349bb167ef933654a37b803d41 (patch)
tree7b64fcfae28eaf123b920f8e4982009936158a9b
parentd119b8b987058274daa2ca5a92dd6887e0d5c24c (diff)
downloadgdk-pixbuf-64cd25f5829f0a349bb167ef933654a37b803d41.tar.gz
Patch from Christian Neumair <chris@gnome-de.org>; only select the first
2005-04-15 Federico Mena Quintero <federico@ximian.com> * gtk/gtkfilechooserdefault.c (pending_select_paths_process): Patch from Christian Neumair <chris@gnome-de.org>; only select the first row if we are in OPEN mode. The only other case we were letting pass through was SELECT_FOLDER, but selecting the first row when changing folders confuses people when folders are actually being selected. Fixes #171885.
-rw-r--r--ChangeLog9
-rw-r--r--ChangeLog.pre-2-109
-rw-r--r--ChangeLog.pre-2-89
-rw-r--r--gtk/gtkfilechooserdefault.c10
4 files changed, 33 insertions, 4 deletions
diff --git a/ChangeLog b/ChangeLog
index 338d4d1a4..11c3c7eac 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,12 @@
+2005-04-15 Federico Mena Quintero <federico@ximian.com>
+
+ * gtk/gtkfilechooserdefault.c (pending_select_paths_process):
+ Patch from Christian Neumair <chris@gnome-de.org>; only select the
+ first row if we are in OPEN mode. The only other case we were
+ letting pass through was SELECT_FOLDER, but selecting the first
+ row when changing folders confuses people when folders are
+ actually being selected. Fixes #171885.
+
2005-04-12 Matthias Clasen <mclasen@redhat.com>
* configure.in: Bump version
diff --git a/ChangeLog.pre-2-10 b/ChangeLog.pre-2-10
index 338d4d1a4..11c3c7eac 100644
--- a/ChangeLog.pre-2-10
+++ b/ChangeLog.pre-2-10
@@ -1,3 +1,12 @@
+2005-04-15 Federico Mena Quintero <federico@ximian.com>
+
+ * gtk/gtkfilechooserdefault.c (pending_select_paths_process):
+ Patch from Christian Neumair <chris@gnome-de.org>; only select the
+ first row if we are in OPEN mode. The only other case we were
+ letting pass through was SELECT_FOLDER, but selecting the first
+ row when changing folders confuses people when folders are
+ actually being selected. Fixes #171885.
+
2005-04-12 Matthias Clasen <mclasen@redhat.com>
* configure.in: Bump version
diff --git a/ChangeLog.pre-2-8 b/ChangeLog.pre-2-8
index 338d4d1a4..11c3c7eac 100644
--- a/ChangeLog.pre-2-8
+++ b/ChangeLog.pre-2-8
@@ -1,3 +1,12 @@
+2005-04-15 Federico Mena Quintero <federico@ximian.com>
+
+ * gtk/gtkfilechooserdefault.c (pending_select_paths_process):
+ Patch from Christian Neumair <chris@gnome-de.org>; only select the
+ first row if we are in OPEN mode. The only other case we were
+ letting pass through was SELECT_FOLDER, but selecting the first
+ row when changing folders confuses people when folders are
+ actually being selected. Fixes #171885.
+
2005-04-12 Matthias Clasen <mclasen@redhat.com>
* configure.in: Bump version
diff --git a/gtk/gtkfilechooserdefault.c b/gtk/gtkfilechooserdefault.c
index 3cc68b907..cec2cae25 100644
--- a/gtk/gtkfilechooserdefault.c
+++ b/gtk/gtkfilechooserdefault.c
@@ -4605,11 +4605,13 @@ pending_select_paths_process (GtkFileChooserDefault *impl)
* that case, the chooser's selection should be what the caller expects,
* as the user can't see that something else got selected. See bug #165264.
*
* Also, we don't select the first file if we are in SAVE or CREATE_FOLDER
* modes. Doing so would change the contents of the filename entry.
*/
- if (GTK_WIDGET_MAPPED (impl)
- && !(impl->action == GTK_FILE_CHOOSER_ACTION_SAVE || impl->action == GTK_FILE_CHOOSER_ACTION_CREATE_FOLDER))
+ if (GTK_WIDGET_MAPPED (impl) && impl->action == GTK_FILE_CHOOSER_ACTION_OPEN)
browse_files_select_first_row (impl);
}
@@ -4605,11 +4605,13 @@ pending_select_paths_process (GtkFileChooserDefault *impl)
* as the user can't see that something else got selected. See bug #165264.
*
- * Also, we don't select the first file if we are in SAVE or CREATE_FOLDER
- * modes. Doing so would change the contents of the filename entry.
+ * Also, we don't select the first file if we are not in OPEN mode. Doing
+ * so would change the contents of the filename entry for SAVE or
+ * CREATE_FOLDER, which is undesired; in SELECT_FOLDER, we don't want to
+ * select a *different* folder from the one into which the user just
+ * navigated.
*/